summaryrefslogtreecommitdiffstats
path: root/Source/cmMSProjectGenerator.h
diff options
context:
space:
mode:
authorBill Hoffman <bill.hoffman@kitware.com>2001-09-06 21:28:24 (GMT)
committerBill Hoffman <bill.hoffman@kitware.com>2001-09-06 21:28:24 (GMT)
commitd204791e45b245fd0a10b2b31ab6ace9a8c3cf65 (patch)
tree183547168a76c000f332f7bad6b77a43f309a09d /Source/cmMSProjectGenerator.h
parentecd4acfb01035d227f68c29ce0f65b2193bbd410 (diff)
downloadCMake-d204791e45b245fd0a10b2b31ab6ace9a8c3cf65.zip
CMake-d204791e45b245fd0a10b2b31ab6ace9a8c3cf65.tar.gz
CMake-d204791e45b245fd0a10b2b31ab6ace9a8c3cf65.tar.bz2
ENH: integrate borland support
Diffstat (limited to 'Source/cmMSProjectGenerator.h')
-rw-r--r--Source/cmMSProjectGenerator.h35
1 files changed, 15 insertions, 20 deletions
diff --git a/Source/cmMSProjectGenerator.h b/Source/cmMSProjectGenerator.h
index 08d8678..64bd936 100644
--- a/Source/cmMSProjectGenerator.h
+++ b/Source/cmMSProjectGenerator.h
@@ -55,22 +55,23 @@ class cmDSWWriter;
class cmMSProjectGenerator : public cmMakefileGenerator
{
public:
- /**
- * Constructor sets the generation of DSW files on.
- */
+ ///! Constructor sets the generation of DSW files on.
cmMSProjectGenerator();
- /**
- * Destructor.
- */
+ ///! Destructor.
~cmMSProjectGenerator();
-
- /**
- * Produce the makefile (in this case a Microsoft Visual C++ project).
- */
+
+ ///! Get the name for the generator.
+ virtual const char* GetName() {return "Visual Studio 6";}
+
+ ///! virtual copy constructor
+ virtual cmMakefileGenerator* CreateObject()
+ { return new cmMSProjectGenerator;}
+
+ ///! Produce the makefile (in this case a Microsoft Visual C++ project).
virtual void GenerateMakefile();
- //! controls the DSW/DSP settings
+ ///! controls the DSW/DSP settings
virtual void SetLocal(bool);
/**
@@ -81,20 +82,14 @@ public:
*/
void BuildDSWOff() {m_BuildDSW = false;}
- /**
- * Turn on the generation of a Microsoft Visual C++ DSW file.
- */
+ ///! Turn on the generation of a Microsoft Visual C++ DSW file.
void BuildDSWOn() {m_BuildDSW = true;}
- /**
- * Retrieve a pointer to a cmDSWWriter instance.
- */
+ ///! Retrieve a pointer to a cmDSWWriter instance.
cmDSWWriter* GetDSWWriter()
{return m_DSWWriter;}
- /**
- * Retrieve a pointer to a cmDSPWriter instance.
- */
+ ///! Retrieve a pointer to a cmDSPWriter instance.
cmDSPWriter* GetDSPWriter()
{return m_DSPWriter;}